import React from "react";
import { useParams } from "react-router-dom";
import { VncScreen } from "react-vnc";
import { VMApi, VMInfo } from "../api/VMApi";
import { useSnackbar } from "../hooks/providers/SnackbarProvider";
import { AsyncWidget } from "../widgets/AsyncWidget";

export function VNCRoute(): React.ReactElement {
  const { uuid } = useParams();

  const [vm, setVM] = React.useState<VMInfo | undefined>();

  const load = async () => {
    setVM(await VMApi.GetSingle(uuid!));
  };

  return (
    <AsyncWidget
      loadKey={uuid}
      load={load}
      errMsg="Failed to load VM information!"
      build={() => <VNCInner vm={vm!} />}
    />
  );
}

function VNCInner(p: { vm: VMInfo }): React.ReactElement {
  const snackbar = useSnackbar();

  const counter = React.useRef(false);
  const [url, setURL] = React.useState<string | undefined>();

  const load = async () => {
    try {
      const u = await VMApi.OneShotVNCURL(p.vm);
      console.info(u);
      if (counter.current === false) {
        counter.current = true;
        setURL(u);
      }
    } catch (e) {
      console.error(e);
      snackbar("Failed to initialize VNC connection!");
    }
  };

  const reconnect = () => {
    counter.current = false;
    setURL(undefined);
  };

  return (
    <AsyncWidget
      loadKey={counter.current}
      load={load}
      ready={url !== undefined && counter.current}
      errMsg="Failed to get a token to initialize VNC connection!"
      build={() => (
        <div
          style={{
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
            height: "100%",
          }}
        >
          <VncScreen
            url={url!}
            onDisconnect={() => {
              console.info("VNC disconnected " + url);
              reconnect();
            }}
          />
        </div>
      )}
    />
  );
}
